@@ -39,6 +39,9 @@ class LocalRequirement:
     def __repr__(self) -> str:
         return f"LocalRequirement({str(self)!r})"
 
+    def to_arg(self, base_dir: Path | None = None) -> str:
+        return str((base_dir / self.path if base_dir else self.path).absolute())
+
 
 @dataclasses.dataclass
 class RequirementSpec:
@@ -109,7 +112,7 @@ class RequirementSpec:
         for url in self.extra_index_urls:
             args += ["--extra-index-url", url]
         if with_requirements:
-            args += [str(x) if isinstance(x, (str, Requirement)) else str(base_dir / x.path) for x in self.requirements]
+            args += [str(x) if isinstance(x, (str, Requirement)) else x.to_arg(base_dir) for x in self.requirements]
         return args
 
     def to_hash(self, algorithm: str = "sha256") -> str:
